A spreadsheet guide is a YAML file that contains directions to where data can be found in a spreadsheet. For an extensive description of this file type, as well as instructions how to create and test the validity, please see the vignettes.
Arguments
- path
The path to the guide file
- verify_hash
If
TRUE, checks that the guide file contains acue.verifiedfield with a valid SHA256 hash, confirming it was signed byvalidate_and_sign.shafter successful CUE validation. Issues a warning when the field is absent; aborts when the field is present but malformed. Does not recompute the hash (useverify_guide.shindata-raw/for full hash verification). Defaults toFALSE.